custom_date_picker library

Classes

CustomCalendarDatePicker
Displays a grid of days for a given month and allows the user to select a date.
FocusedDate
InheritedWidget indicating what the current focused date is for its children.
YearPicker
A scrollable grid of years to allow picking a year.